@@ -551,71 +551,6 @@ void conline::learn()
     clock.tock("core");
 }
 
-Rcpp::List conline::output()
-{
-    clock.tick("wrangle");
-
-    // 1-Indexing for R-Output
-    opt_index += 1;
-
-    Rcpp::List model_data = Rcpp::List::create(
-        Rcpp::Named("y") = y,
-        Rcpp::Named("experts") = experts,
-        Rcpp::Named("tau") = tau);
-
-    Rcpp::List model_parameters = Rcpp::List::create(
-        Rcpp::Named("lead_time") = lead_time,
-        Rcpp::Named("loss_function") = loss_function,
-        Rcpp::Named("loss_parameter") = loss_parameter,
-        Rcpp::Named("loss_gradient") = loss_gradient,
-        Rcpp::Named("method") = method,
-        Rcpp::Named("forget_past_performance") = forget_past_performance,
-        Rcpp::Named("allow_quantile_crossing") = allow_quantile_crossing,
-        Rcpp::Named("save_past_performance") = save_past_performance,
-        Rcpp::Named("save_predictions_grid") = save_predictions_grid);
-
-    Rcpp::List model_objects = Rcpp::List::create(
-        Rcpp::Named("weights_tmp") = weights_tmp,
-        Rcpp::Named("predictions_grid") = predictions_grid,
-        Rcpp::Named("cum_performance") = cum_performance,
-        Rcpp::Named("hat_pr") = hat_pr,
-        Rcpp::Named("hat_mv") = hat_mv,
-        Rcpp::Named("basis_pr") = basis_pr,
-        Rcpp::Named("basis_mv") = basis_mv,
-        Rcpp::Named("V") = V,
-        Rcpp::Named("E") = E,
-        Rcpp::Named("eta") = eta,
-        Rcpp::Named("R") = R,
-        Rcpp::Named("beta") = beta,
-        Rcpp::Named("beta0field") = beta0field);
-
-    Rcpp::List model_spec = Rcpp::List::create(
-        Rcpp::Named("data") = model_data,
-        Rcpp::Named("parameters") = model_parameters,
-        Rcpp::Named("objects") = model_objects);
-
-    Rcpp::List out = Rcpp::List::create(
-        Rcpp::Named("predictions") = predictions,
-        Rcpp::Named("predictions_got_sorted") = predictions_got_sorted,
-        Rcpp::Named("weights") = weights,
-        Rcpp::Named("forecaster_loss") = loss_for,
-        Rcpp::Named("experts_loss") = loss_exp,
-        Rcpp::Named("past_performance") = past_performance,
-        Rcpp::Named("opt_index") = opt_index,
-        Rcpp::Named("parametergrid") = params,
-        Rcpp::Named("params_basis_pr") = params_basis_pr,
-        Rcpp::Named("params_basis_mv") = params_basis_mv,
-        Rcpp::Named("params_hat_pr") = params_hat_pr,
-        Rcpp::Named("params_hat_mv") = params_hat_mv,
-        Rcpp::Named("specification") = model_spec);
-
-    out.attr("class") = "online";
-
-    clock.tock("wrangle");
-    // Rcpp::List out;
-    return out;
-}
-
 void conline::init_update(
     Rcpp::List &object,
     arma::mat &new_y,
