@@ -18,7 +18,12 @@ RCPP_MODULE(conlineEx)
       .field("loss_gradient", &conline::loss_gradient)
       .field("method", &conline::method)
       .field("save_past_performance", &conline::save_past_performance)
+      .field("past_performance", &conline::past_performance)
+      .field("cum_performance", &conline::cum_performance)
       .field("save_predictions_grid", &conline::save_predictions_grid)
+      .field("predictions_grid", &conline::predictions_grid)
+      .field("predictions", &conline::predictions)
+      .field("predictions_got_sorted", &conline::predictions_got_sorted)
       .field("forget_past_performance", &conline::forget_past_performance)
       .field("allow_quantile_crossing", &conline::allow_quantile_crossing)
       .field("trace", &conline::trace)
@@ -27,23 +32,33 @@ RCPP_MODULE(conlineEx)
       .field("hat_pr", &conline::hat_pr)
       .field("hat_mv", &conline::hat_mv)
       .field("w0", &conline::w0)
+      .field("beta0field", &conline::beta0field)
+      .field("beta", &conline::beta)
+      .field("weights", &conline::weights)
+      .field("weights_tmp", &conline::weights_tmp)
       .field("R0", &conline::R0)
+      .field("V", &conline::V)
+      .field("E", &conline::E)
+      .field("R", &conline::R)
+      .field("loss_exp", &conline::loss_exp)
+      .field("loss_for", &conline::loss_for)
+      .field("eta", &conline::eta)
       .field("params", &conline::params)
       .field("params_basis_pr", &conline::params_basis_pr)
       .field("params_basis_mv", &conline::params_basis_mv)
       .field("params_hat_pr", &conline::params_hat_pr)
       .field("params_hat_mv", &conline::params_hat_mv)
+      .field("opt_index", &conline::opt_index)
       .field("loss_array", &conline::loss_array)
       .field("regret_array", &conline::regret_array)
       .method("set_defaults", &conline::set_defaults)
       .method("set_grid_objects", &conline::set_grid_objects)
       .method("learn", &conline::learn)
-      .method("output", &conline::output)
       .method("init_update", &conline::init_update)
       .method("getT", &conline::getT)
       .method("getD", &conline::getD)
       .method("getP", &conline::getP)
       .method("getK", &conline::getK)
       .method("getX", &conline::getX)
-      .method("teardown", &conline::teardown);
+      .method("get_times", &conline::get_times);
 }
